pub async fn has_pending_manual_reviews_in_chapter(
conn: &mut PgConnection,
user_id: Uuid,
chapter_id: Uuid,
) -> ModelResult<bool>Expand description
Returns true when user has chapter exercises pending teacher review.
pub async fn has_pending_manual_reviews_in_chapter(
conn: &mut PgConnection,
user_id: Uuid,
chapter_id: Uuid,
) -> ModelResult<bool>Returns true when user has chapter exercises pending teacher review.